@@ -19,6 +19,8 @@
 
 #include <Wt/AsioWrapper/system_error.hpp>
 
+#include <mutex>
+
 namespace Wt {
   namespace Auth {
 
@@ -156,7 +158,7 @@ public:
    *
    * The scope represents how much protected information the web
    * application wants to access, and in what way.
-   * 
+   *
    * By default, this is the scope given at the creation of the process
    * but this can be changed by overriding this function.
    *
@@ -322,16 +324,16 @@ protected:
   virtual void setError(const WString& e);
 
   /*! \brief Return the authorization endpoint URL.
-   * 
+   *
    * This is a remote URL which hosts the %OAuth authorization user
    * interface. This URL is loaded in the popup window at the start of
    * the authorization process.
-   * 
+   *
    * By default, this is the authorization endpoint URL configured in
    * the OAuthService of this process, but this can be changed by
    * overriding this function.
-   * 
-   * \sa OAuthService::authorizationEndpoint() 
+   *
+   * \sa OAuthService::authorizationEndpoint()
    */
   virtual std::string authorizationEndpoint() const;
 
@@ -352,6 +354,8 @@ private:
   std::unique_ptr<OAuthRedirectEndpoint> redirectEndpoint_;
   std::unique_ptr<Http::Client> httpClient_;
 
+  std::mutex updateMutex_;
+
   // onOAuthDone() gets called from WApplication::unsuspended(), keeping
   // the connection object allows us to disconnect after it's done
   Wt::Signals::connection doneCallbackConnection_;
