@@ -611,9 +611,9 @@ public:
    * By passing an empty \p locale, the default locale is
    * chosen.
    *
-   * By default, when the locale is changed, refresh() is called, 
+   * By default, when the locale is changed, refresh() is called,
    * which will resolve the strings of the current user-interface
-   * in the new locale. This can be changed by having the 
+   * in the new locale. This can be changed by having the
    * \p doRefresh parameter set to \p false.
    *
    * At construction, the locale is copied from the environment
@@ -2454,6 +2454,7 @@ private:
   EventSignal<> showLoadingIndicator_, hideLoadingIndicator_;
   JSignal<> unloaded_;
   JSignal<> idleTimeout_;
+  Signal<> focusChanged_;
 
   // Track cookies added over application lifetime.
   // WEnvironment does not update itself, so `setCookie` is not reflected by it.
@@ -2483,6 +2484,7 @@ private:
   std::string resourceMapKey(WResource *resource);
   std::string addExposedResource(WResource *resource);
   bool removeExposedResource(WResource *resource);
+  void exposeBotResources();
   WResource *decodeExposedResource(const std::string& resourceMapKey) const;
   WResource *decodeExposedResource(const std::string& resourceMapKey,
                                    unsigned long rand) const;
@@ -2527,6 +2529,7 @@ private:
   void endWaitingAtLock(int id);
 #endif // WT_TARGET_JAVA
 
+  void setAsFocus(const std::string& id);
   std::string focus() const { return focusId_; }
   int selectionStart() const { return selectionStart_; }
   int selectionEnd() const { return selectionEnd_; }
@@ -2558,6 +2561,7 @@ private:
   friend class EventSignalBase;
   friend class JavaScriptEvent;
   friend class UpdateLockImpl;
+  friend class WCompositeWidget;
   friend class WContainerWidget;
   friend class WDialog;
   friend class WFileUpload;
@@ -2565,6 +2569,7 @@ private:
   friend class WLineEdit;
   friend class WMenu;
   friend class WResource;
+  friend class WSelfDeletingResource;
   friend class WSound;
   friend class WString;
   friend class WTextArea;
